summaryrefslogtreecommitdiff
path: root/errors.go
diff options
context:
space:
mode:
Diffstat (limited to 'errors.go')
-rw-r--r--errors.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/errors.go b/errors.go
index c9d18cb..64fc711 100644
--- a/errors.go
+++ b/errors.go
@@ -109,9 +109,9 @@ var (
// ErrWorkbookExt defined the error message on receive an unsupported
// workbook extension.
ErrWorkbookExt = errors.New("unsupported workbook extension")
// ErrMaxFileNameLength defined the error message on receive the file name
// length overflow.
- ErrMaxFileNameLength = errors.New("file name length exceeds maximum limit")
+ ErrMaxFilePathLength = errors.New("file path length exceeds maximum limit")
// ErrEncrypt defined the error message on encryption spreadsheet.
ErrEncrypt = errors.New("not support encryption currently")
// ErrUnknownEncryptMechanism defined the error message on unsupported
@@ -109,9 +109,9 @@ var (
// workbook extension.
ErrWorkbookExt = errors.New("unsupported workbook extension")
- // ErrMaxFileNameLength defined the error message on receive the file name
+ // ErrMaxFilePathLength defined the error message on receive the file path
// length overflow.